@@ -22,14 +22,11 @@
 
 #include "sound-juicer.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <sys/time.h>
-#include <unistd.h> 
-#include <errno.h>
-#include <stdlib.h>
+#include <time.h>
 
 #include <glib/glist.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkmain.h>
@@ -41,6 +38,7 @@
 #include "sj-error.h"
 #include "sj-extracting.h"
 #include "sj-util.h"
+#include "sj-play.h"
 
 typedef struct {
   int seconds;
@@ -62,7 +60,7 @@ static GtkWidget *track_progress, *album_progress;
 static GtkWidget *progress_label;
 
 /** The widgets in the main UI */
-static GtkWidget *extract_button, *reread_button, *title_entry, *artist_entry, *genre_combo, *track_listview;
+static GtkWidget *extract_button, *title_entry, *artist_entry, *genre_entry, *track_listview;
 
 /** The menuitem in the main menu */
 static GtkWidget *extract_menuitem, *reread_menuitem, *select_all_menuitem, *deselect_all_menuitem;
@@ -152,11 +150,10 @@ cleanup (void)
   pending = NULL;
   track = NULL;
   gtk_widget_set_sensitive (extract_button, TRUE);
-  gtk_widget_set_sensitive (reread_button, TRUE);
   gtk_widget_set_sensitive (track_listview, TRUE);
   gtk_widget_set_sensitive (title_entry, TRUE);
   gtk_widget_set_sensitive (artist_entry, TRUE);
-  gtk_widget_set_sensitive (genre_combo, TRUE);
+  gtk_widget_set_sensitive (genre_entry, TRUE);
   /* Enabling the Menuitem */ 
   gtk_widget_set_sensitive (extract_menuitem, TRUE);
   gtk_widget_set_sensitive (reread_menuitem, TRUE);
@@ -169,34 +166,37 @@ cleanup (void)
  * Return true on continue, false on skip.
  */
 static gboolean
-check_for_file (const char* filename)
+check_for_file (const char* uri)
 {
-  struct stat stats;
-  int ret;
+  GnomeVFSFileInfo info;
+  GnomeVFSResult res;
   GtkWidget *dialog;
-  char *utf8_filename;
+  char *filename, *size;
+  int ret;
   
-  ret = stat (filename, &stats);
-  if (ret == -1) {
-    if (errno == ENOENT) {
-      return TRUE;
-    }
-    g_warning ("stat failed: %s", g_strerror (errno));
+  res = gnome_vfs_get_file_info (uri, &info, GNOME_VFS_FILE_INFO_DEFAULT);
+  if (res == GNOME_VFS_ERROR_NOT_FOUND)
+    return TRUE;
+  if (res != GNOME_VFS_OK) {
+    /* TODO: display an error dialog */
+    g_warning ("Cannot get file info: %s", gnome_vfs_result_to_string (res));
     return FALSE;
   }
-  if (stats.st_size < (100000)) {
+  if (info.size < (100000)) {
     /* The file exists but is small, assume overwriting */
     return TRUE;
   }
   /* Otherwise the file exists and is large, ask user if they really
      want to overwrite it */
-  utf8_filename = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
+  filename = gnome_vfs_format_uri_for_display (uri);
+  size = gnome_vfs_format_file_size_for_display (info.size);
   dialog = gtk_message_dialog_new (GTK_WINDOW (main_window), GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_NONE,
-                                   _("A file called '%s' exists, size %lu kB.\nDo you want to skip this track or overwrite it?"),
-                                   utf8_filename, (unsigned long)(stats.st_size / 1000));
-  g_free (utf8_filename);
+                                   _("A file called '%s' exists, size %s.\nDo you want to skip this track or overwrite it?"),
+                                   filename, size);
+  g_free (filename);
+  g_free (size);
   gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Skip"), GTK_RESPONSE_CANCEL);
   gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Overwrite"), GTK_RESPONSE_ACCEPT);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
@@ -224,7 +224,7 @@ create_directory_for (const char* url, GError **error)
   gnome_vfs_uri_unref (uri);
 
   res = make_directory_with_parents_for_uri (parent, 0777);
-  if (res != GNOME_VFS_OK) {
+  if (res != GNOME_VFS_OK && res != GNOME_VFS_ERROR_FILE_EXISTS) {
     g_set_error (error, SJ_ERROR, SJ_ERROR_CD_PERMISSION_ERROR, g_strdup (gnome_vfs_result_to_string (res)));
     return NULL;
   }
@@ -551,6 +551,9 @@ on_progress_cancel_clicked (GtkWidget *button, gpointer user_data)
 void
 on_extract_activate (GtkWidget *button, gpointer user_data)
 {
+  /* first make sure we're not playing, we cannot share the resource */
+  stop_playback ();
+
   /* Populate the pending list */
   pending = NULL;
   total_extracting = 0;
@@ -579,10 +582,9 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
     album_progress = glade_xml_get_widget (glade, "album_progress");
     progress_label = glade_xml_get_widget (glade, "progress_label");
     extract_button = glade_xml_get_widget (glade, "extract_button");
-    reread_button = glade_xml_get_widget (glade, "reread_button");
     title_entry = glade_xml_get_widget (glade, "title_entry");
     artist_entry = glade_xml_get_widget (glade, "artist_entry");
-    genre_combo = glade_xml_get_widget (glade, "genre_combo");
+    genre_entry = glade_xml_get_widget (glade, "genre_entry");
     track_listview = glade_xml_get_widget (glade, "track_listview");
     
     extract_menuitem = glade_xml_get_widget (glade, "extract_menuitem");
@@ -604,10 +606,9 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
 
   /* Disable the widgets in the main UI*/
   gtk_widget_set_sensitive (extract_button, FALSE);
-  gtk_widget_set_sensitive (reread_button, FALSE);
   gtk_widget_set_sensitive (title_entry, FALSE);
   gtk_widget_set_sensitive (artist_entry, FALSE);
-  gtk_widget_set_sensitive (genre_combo, FALSE);
+  gtk_widget_set_sensitive (genre_entry, FALSE);
   gtk_widget_set_sensitive (track_listview, FALSE);
 
   /* Disable the menuitems in the main menu*/	
