@@ -24,6 +24,7 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <string.h>
 #include <glib/gerror.h>
 #include <glib/gtypes.h>
 #include <glib/gi18n.h>
@@ -222,6 +223,16 @@ static void error_cb (GstElement *element, GObject *arg, GError *err, gchar *arg
                  0, err);
 }
 
+/**
+ * Callback from the gnomevfssink to say that its about to overwrite a file.
+ * For now, Just Say Yes.  If this API will stay in 0.9, then rewrite
+ * SjExtractor.
+ */
+static gboolean just_say_yes (GstElement *element, gpointer filename, gpointer user_data)
+{
+  return TRUE;
+}
+
 static void build_pipeline (SjExtractor *extractor)
 {
   SjExtractorPrivate *priv;
@@ -275,6 +286,7 @@ static void build_pipeline (SjExtractor *extractor)
                  _("Could not create GStreamer file output"));
     return;
   }
+  g_signal_connect (G_OBJECT (priv->filesink), "allow-overwrite", G_CALLBACK (just_say_yes), extractor);
 
   /* Add the elements to the pipeline */
   gst_bin_add (GST_BIN (priv->pipeline), priv->cdparanoia);
@@ -416,23 +428,21 @@ void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *tra
                             GST_TAG_TRACK_NUMBER, track->number,
                             GST_TAG_TRACK_COUNT, track->album->number,
                             GST_TAG_ALBUM, track->album->title,
+                            GST_TAG_ENCODER, _("Sound Juicer"),
+                            GST_TAG_ENCODER_VERSION, VERSION,
                             GST_TAG_MUSICBRAINZ_ALBUMID, track->album->album_id,
                             GST_TAG_MUSICBRAINZ_ALBUMARTISTID, track->album->artist_id,
                             GST_TAG_MUSICBRAINZ_ARTISTID, track->artist_id,
                             GST_TAG_MUSICBRAINZ_TRACKID, track->track_id,
-                            GST_TAG_ENCODER, _("Sound Juicer"),
-                            GST_TAG_ENCODER_VERSION, VERSION,
                             NULL);
-        if (track->genre != LAST_GENRE) {
+        if (track->album->genre != NULL && strcmp (track->album->genre, "") != 0) {
           gst_tag_setter_add (GST_TAG_SETTER (elt->data),
-                              /* TODO: is APPEND right? */
                               GST_TAG_MERGE_APPEND,
-                              GST_TAG_GENRE, sj_genre_name (track->genre),
+                              GST_TAG_GENRE, track->album->genre,
                               NULL);
         }
         if (track->album->release_date) {
           gst_tag_setter_add (GST_TAG_SETTER (elt->data),
-                              /* TODO: is APPEND right? */
                               GST_TAG_MERGE_APPEND,
                               GST_TAG_DATE, g_date_get_julian (track->album->release_date),
                               NULL);
