@@ -64,6 +64,7 @@ extern gboolean extracting;
  * The columns in the list view
  */
 typedef enum {
+  COLUMN_STATE,
   COLUMN_EXTRACT,
   COLUMN_NUMBER,
   COLUMN_TITLE,
@@ -73,6 +74,12 @@ typedef enum {
   COLUMN_TOTAL
 } ViewColumn;
 
+typedef enum {
+  STATE_IDLE,
+  STATE_PLAYING,
+  STATE_EXTRACTING
+} TrackState;
+
 /**
  * The GtkTreeModel which all of the tracks are stored in
  */
@@ -86,7 +93,7 @@ extern NautilusBurnDrive *drive;
 /**
  * The root path to write files too
  */
-extern const char *base_path;
+extern const char *base_uri;
 
 /**
  * The pattern to expand when naming folders
@@ -120,6 +127,7 @@ extern gboolean autostart;
 #define GCONF_DEVICE GCONF_ROOT "/device"
 #define GCONF_EJECT GCONF_ROOT "/eject"
 #define GCONF_BASEPATH GCONF_ROOT "/base_path"
+#define GCONF_BASEURI GCONF_ROOT "/base_uri"
 #define GCONF_FILE_PATTERN GCONF_ROOT "/file_pattern"
 #define GCONF_PATH_PATTERN GCONF_ROOT "/path_pattern"
 #define GCONF_AUDIO_PROFILE GCONF_ROOT "/audio_profile"
@@ -132,4 +140,7 @@ extern gboolean autostart;
 #define GCONF_HTTP_PROXY GCONF_PROXY_ROOT "/host"
 #define GCONF_HTTP_PROXY_PORT GCONF_PROXY_ROOT "/port"
 
+/* TODO: need to add a SjWindow object or something */
+void sj_main_set_title (const char* detail);
+
 #endif /* SOUND_JUICER_H */
